Class: Aws::AppFabric::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::AppFabric::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-appfabric/client.rb,
sig/client.rbs
Overview
An API client for AppFabric. To construct a client, you need to configure a :region and :credentials.
client = Aws::AppFabric::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _BatchGetUserAccessTasksResponseSuccess, _ConnectAppAuthorizationResponseSuccess, _CreateAppAuthorizationResponseSuccess, _CreateAppBundleResponseSuccess, _CreateIngestionDestinationResponseSuccess, _CreateIngestionResponseSuccess, _DeleteAppAuthorizationResponseSuccess, _DeleteAppBundleResponseSuccess, _DeleteIngestionDestinationResponseSuccess, _DeleteIngestionResponseSuccess, _GetAppAuthorizationResponseSuccess, _GetAppBundleResponseSuccess, _GetIngestionDestinationResponseSuccess, _GetIngestionResponseSuccess, _ListAppAuthorizationsResponseSuccess, _ListAppBundlesResponseSuccess, _ListIngestionDestinationsResponseSuccess, _ListIngestionsResponseSuccess, _ListTagsForResourceResponseSuccess, _StartIngestionResponseSuccess, _StartUserAccessTasksResponseSuccess, _StopIngestionResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateAppAuthorizationResponseSuccess, _UpdateIngestionDestinationResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_get_user_access_tasks(params = {}) ⇒ Types::BatchGetUserAccessTasksResponse
Gets user access details in a batch request.
-
#connect_app_authorization(params = {}) ⇒ Types::ConnectAppAuthorizationResponse
Establishes a connection between Amazon Web Services AppFabric and an application, which allows AppFabric to call the APIs of the application.
-
#create_app_authorization(params = {}) ⇒ Types::CreateAppAuthorizationResponse
Creates an app authorization within an app bundle, which allows AppFabric to connect to an application.
-
#create_app_bundle(params = {}) ⇒ Types::CreateAppBundleResponse
Creates an app bundle to collect data from an application using AppFabric.
-
#create_ingestion(params = {}) ⇒ Types::CreateIngestionResponse
Creates a data ingestion for an application.
-
#create_ingestion_destination(params = {}) ⇒ Types::CreateIngestionDestinationResponse
Creates an ingestion destination, which specifies how an application's ingested data is processed by Amazon Web Services AppFabric and where it's delivered.
-
#delete_app_authorization(params = {}) ⇒ Struct
Deletes an app authorization.
-
#delete_app_bundle(params = {}) ⇒ Struct
Deletes an app bundle.
-
#delete_ingestion(params = {}) ⇒ Struct
Deletes an ingestion.
-
#delete_ingestion_destination(params = {}) ⇒ Struct
Deletes an ingestion destination.
-
#get_app_authorization(params = {}) ⇒ Types::GetAppAuthorizationResponse
Returns information about an app authorization.
-
#get_app_bundle(params = {}) ⇒ Types::GetAppBundleResponse
Returns information about an app bundle.
-
#get_ingestion(params = {}) ⇒ Types::GetIngestionResponse
Returns information about an ingestion.
-
#get_ingestion_destination(params = {}) ⇒ Types::GetIngestionDestinationResponse
Returns information about an ingestion destination.
-
#list_app_authorizations(params = {}) ⇒ Types::ListAppAuthorizationsResponse
Returns a list of all app authorizations configured for an app bundle.
-
#list_app_bundles(params = {}) ⇒ Types::ListAppBundlesResponse
Returns a list of app bundles.
-
#list_ingestion_destinations(params = {}) ⇒ Types::ListIngestionDestinationsResponse
Returns a list of all ingestion destinations configured for an ingestion.
-
#list_ingestions(params = {}) ⇒ Types::ListIngestionsResponse
Returns a list of all ingestions configured for an app bundle.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of tags for a resource.
-
#start_ingestion(params = {}) ⇒ Struct
Starts (enables) an ingestion, which collects data from an application.
-
#start_user_access_tasks(params = {}) ⇒ Types::StartUserAccessTasksResponse
Starts the tasks to search user access status for a specific email address.
-
#stop_ingestion(params = {}) ⇒ Struct
Stops (disables) an ingestion.
-
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes a tag or tags from a resource.
-
#update_app_authorization(params = {}) ⇒ Types::UpdateAppAuthorizationResponse
Updates an app authorization within an app bundle, which allows AppFabric to connect to an application.
-
#update_ingestion_destination(params = {}) ⇒ Types::UpdateIngestionDestinationResponse
Updates an ingestion destination, which specifies how an application's ingested data is processed by Amazon Web Services AppFabric and where it's delivered.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-appfabric/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1850 1851 1852 |
# File 'lib/aws-sdk-appfabric/client.rb', line 1850 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1853 1854 1855 |
# File 'lib/aws-sdk-appfabric/client.rb', line 1853 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#batch_get_user_access_tasks(params = {}) ⇒ Types::BatchGetUserAccessTasksResponse
Gets user access details in a batch request.
This action polls data from the tasks that are kicked off by the
StartUserAccessTasks action.
86 |
# File 'sig/client.rbs', line 86
def batch_get_user_access_tasks: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1823 1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 |
# File 'lib/aws-sdk-appfabric/client.rb', line 1823 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::AppFabric') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-appfabric' context[:gem_version] = '1.44.0' Seahorse::Client::Request.new(handlers, context) end |
#connect_app_authorization(params = {}) ⇒ Types::ConnectAppAuthorizationResponse
Establishes a connection between Amazon Web Services AppFabric and an application, which allows AppFabric to call the APIs of the application.
97 |
# File 'sig/client.rbs', line 97
def connect_app_authorization: (
|
#create_app_authorization(params = {}) ⇒ Types::CreateAppAuthorizationResponse
Creates an app authorization within an app bundle, which allows AppFabric to connect to an application.
112 |
# File 'sig/client.rbs', line 112
def create_app_authorization: (
|
#create_app_bundle(params = {}) ⇒ Types::CreateAppBundleResponse
Creates an app bundle to collect data from an application using AppFabric.
136 |
# File 'sig/client.rbs', line 136
def create_app_bundle: (
|
#create_ingestion(params = {}) ⇒ Types::CreateIngestionResponse
Creates a data ingestion for an application.
153 |
# File 'sig/client.rbs', line 153
def create_ingestion: (
|
#create_ingestion_destination(params = {}) ⇒ Types::CreateIngestionDestinationResponse
Creates an ingestion destination, which specifies how an application's ingested data is processed by Amazon Web Services AppFabric and where it's delivered.
173 |
# File 'sig/client.rbs', line 173
def create_ingestion_destination: (
|
#delete_app_authorization(params = {}) ⇒ Struct
Deletes an app authorization. You must delete the associated ingestion before you can delete an app authorization.
197 |
# File 'sig/client.rbs', line 197
def delete_app_authorization: (
|
#delete_app_bundle(params = {}) ⇒ Struct
Deletes an app bundle. You must delete all associated app authorizations before you can delete an app bundle.
207 |
# File 'sig/client.rbs', line 207
def delete_app_bundle: (
|
#delete_ingestion(params = {}) ⇒ Struct
Deletes an ingestion. You must stop (disable) the ingestion and you must delete all associated ingestion destinations before you can delete an app ingestion.
216 |
# File 'sig/client.rbs', line 216
def delete_ingestion: (
|
#delete_ingestion_destination(params = {}) ⇒ Struct
Deletes an ingestion destination.
This deletes the association between an ingestion and it's destination. It doesn't delete previously ingested data or the storage destination, such as the Amazon S3 bucket where the data is delivered. If the ingestion destination is deleted while the associated ingestion is enabled, the ingestion will fail and is eventually disabled.
226 |
# File 'sig/client.rbs', line 226
def delete_ingestion_destination: (
|
#get_app_authorization(params = {}) ⇒ Types::GetAppAuthorizationResponse
Returns information about an app authorization.
238 |
# File 'sig/client.rbs', line 238
def get_app_authorization: (
|
#get_app_bundle(params = {}) ⇒ Types::GetAppBundleResponse
Returns information about an app bundle.
249 |
# File 'sig/client.rbs', line 249
def get_app_bundle: (
|
#get_ingestion(params = {}) ⇒ Types::GetIngestionResponse
Returns information about an ingestion.
259 |
# File 'sig/client.rbs', line 259
def get_ingestion: (
|
#get_ingestion_destination(params = {}) ⇒ Types::GetIngestionDestinationResponse
Returns information about an ingestion destination.
270 |
# File 'sig/client.rbs', line 270
def get_ingestion_destination: (
|
#list_app_authorizations(params = {}) ⇒ Types::ListAppAuthorizationsResponse
Returns a list of all app authorizations configured for an app bundle.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
283 |
# File 'sig/client.rbs', line 283
def list_app_authorizations: (
|
#list_app_bundles(params = {}) ⇒ Types::ListAppBundlesResponse
Returns a list of app bundles.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
296 |
# File 'sig/client.rbs', line 296
def list_app_bundles: (
|
#list_ingestion_destinations(params = {}) ⇒ Types::ListIngestionDestinationsResponse
Returns a list of all ingestion destinations configured for an ingestion.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
308 |
# File 'sig/client.rbs', line 308
def list_ingestion_destinations: (
|
#list_ingestions(params = {}) ⇒ Types::ListIngestionsResponse
Returns a list of all ingestions configured for an app bundle.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
322 |
# File 'sig/client.rbs', line 322
def list_ingestions: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of tags for a resource.
334 |
# File 'sig/client.rbs', line 334
def list_tags_for_resource: (
|
#start_ingestion(params = {}) ⇒ Struct
Starts (enables) an ingestion, which collects data from an application.
343 |
# File 'sig/client.rbs', line 343
def start_ingestion: (
|
#start_user_access_tasks(params = {}) ⇒ Types::StartUserAccessTasksResponse
Starts the tasks to search user access status for a specific email address.
The tasks are stopped when the user access status data is found. The tasks are terminated when the API calls to the application time out.
354 |
# File 'sig/client.rbs', line 354
def start_user_access_tasks: (
|
#stop_ingestion(params = {}) ⇒ Struct
Stops (disables) an ingestion.
364 |
# File 'sig/client.rbs', line 364
def stop_ingestion: (
|
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified resource.
374 |
# File 'sig/client.rbs', line 374
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes a tag or tags from a resource.
389 |
# File 'sig/client.rbs', line 389
def untag_resource: (
|
#update_app_authorization(params = {}) ⇒ Types::UpdateAppAuthorizationResponse
Updates an app authorization within an app bundle, which allows AppFabric to connect to an application.
If the app authorization was in a connected state, updating the app
authorization will set it back to a PendingConnect state.
400 |
# File 'sig/client.rbs', line 400
def update_app_authorization: (
|
#update_ingestion_destination(params = {}) ⇒ Types::UpdateIngestionDestinationResponse
Updates an ingestion destination, which specifies how an application's ingested data is processed by Amazon Web Services AppFabric and where it's delivered.
416 |
# File 'sig/client.rbs', line 416
def update_ingestion_destination: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1843 1844 1845 |
# File 'lib/aws-sdk-appfabric/client.rb', line 1843 def waiter_names [] end |