Class: Aws::AppFabric::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::AppFabric::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-appfabric/client.rb
Overview
An API client for AppFabric. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::AppFabric::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_get_user_access_tasks(params = {}) ⇒ Types::BatchGetUserAccessTasksResponse
Gets user access details in a batch request.
-
#connect_app_authorization(params = {}) ⇒ Types::ConnectAppAuthorizationResponse
Establishes a connection between Amazon Web Services AppFabric and an application, which allows AppFabric to call the APIs of the application.
-
#create_app_authorization(params = {}) ⇒ Types::CreateAppAuthorizationResponse
Creates an app authorization within an app bundle, which allows AppFabric to connect to an application.
-
#create_app_bundle(params = {}) ⇒ Types::CreateAppBundleResponse
Creates an app bundle to collect data from an application using AppFabric.
-
#create_ingestion(params = {}) ⇒ Types::CreateIngestionResponse
Creates a data ingestion for an application.
-
#create_ingestion_destination(params = {}) ⇒ Types::CreateIngestionDestinationResponse
Creates an ingestion destination, which specifies how an application’s ingested data is processed by Amazon Web Services AppFabric and where it’s delivered.
-
#delete_app_authorization(params = {}) ⇒ Struct
Deletes an app authorization.
-
#delete_app_bundle(params = {}) ⇒ Struct
Deletes an app bundle.
-
#delete_ingestion(params = {}) ⇒ Struct
Deletes an ingestion.
-
#delete_ingestion_destination(params = {}) ⇒ Struct
Deletes an ingestion destination.
-
#get_app_authorization(params = {}) ⇒ Types::GetAppAuthorizationResponse
Returns information about an app authorization.
-
#get_app_bundle(params = {}) ⇒ Types::GetAppBundleResponse
Returns information about an app bundle.
-
#get_ingestion(params = {}) ⇒ Types::GetIngestionResponse
Returns information about an ingestion.
-
#get_ingestion_destination(params = {}) ⇒ Types::GetIngestionDestinationResponse
Returns information about an ingestion destination.
-
#list_app_authorizations(params = {}) ⇒ Types::ListAppAuthorizationsResponse
Returns a list of all app authorizations configured for an app bundle.
-
#list_app_bundles(params = {}) ⇒ Types::ListAppBundlesResponse
Returns a list of app bundles.
-
#list_ingestion_destinations(params = {}) ⇒ Types::ListIngestionDestinationsResponse
Returns a list of all ingestion destinations configured for an ingestion.
-
#list_ingestions(params = {}) ⇒ Types::ListIngestionsResponse
Returns a list of all ingestions configured for an app bundle.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of tags for a resource.
-
#start_ingestion(params = {}) ⇒ Struct
Starts (enables) an ingestion, which collects data from an application.
-
#start_user_access_tasks(params = {}) ⇒ Types::StartUserAccessTasksResponse
Starts the tasks to search user access status for a specific email address.
-
#stop_ingestion(params = {}) ⇒ Struct
Stops (disables) an ingestion.
-
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes a tag or tags from a resource.
-
#update_app_authorization(params = {}) ⇒ Types::UpdateAppAuthorizationResponse
Updates an app authorization within an app bundle, which allows AppFabric to connect to an application.
-
#update_ingestion_destination(params = {}) ⇒ Types::UpdateIngestionDestinationResponse
Updates an ingestion destination, which specifies how an application’s ingested data is processed by Amazon Web Services AppFabric and where it’s delivered.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-appfabric/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1850 1851 1852 |
# File 'lib/aws-sdk-appfabric/client.rb', line 1850 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1853 1854 1855 |
# File 'lib/aws-sdk-appfabric/client.rb', line 1853 def errors_module Errors end |
Instance Method Details
#batch_get_user_access_tasks(params = {}) ⇒ Types::BatchGetUserAccessTasksResponse
Gets user access details in a batch request.
This action polls data from the tasks that are kicked off by the ‘StartUserAccessTasks` action.
521 522 523 524 |
# File 'lib/aws-sdk-appfabric/client.rb', line 521 def batch_get_user_access_tasks(params = {}, = {}) req = build_request(:batch_get_user_access_tasks, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1823 1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 |
# File 'lib/aws-sdk-appfabric/client.rb', line 1823 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::AppFabric') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-appfabric' context[:gem_version] = '1.42.0' Seahorse::Client::Request.new(handlers, context) end |
#connect_app_authorization(params = {}) ⇒ Types::ConnectAppAuthorizationResponse
Establishes a connection between Amazon Web Services AppFabric and an application, which allows AppFabric to call the APIs of the application.
574 575 576 577 |
# File 'lib/aws-sdk-appfabric/client.rb', line 574 def (params = {}, = {}) req = build_request(:connect_app_authorization, params) req.send_request() end |
#create_app_authorization(params = {}) ⇒ Types::CreateAppAuthorizationResponse
Creates an app authorization within an app bundle, which allows AppFabric to connect to an application.
707 708 709 710 |
# File 'lib/aws-sdk-appfabric/client.rb', line 707 def (params = {}, = {}) req = build_request(:create_app_authorization, params) req.send_request() end |
#create_app_bundle(params = {}) ⇒ Types::CreateAppBundleResponse
Creates an app bundle to collect data from an application using AppFabric.
772 773 774 775 |
# File 'lib/aws-sdk-appfabric/client.rb', line 772 def create_app_bundle(params = {}, = {}) req = build_request(:create_app_bundle, params) req.send_request() end |
#create_ingestion(params = {}) ⇒ Types::CreateIngestionResponse
Creates a data ingestion for an application.
879 880 881 882 |
# File 'lib/aws-sdk-appfabric/client.rb', line 879 def create_ingestion(params = {}, = {}) req = build_request(:create_ingestion, params) req.send_request() end |
#create_ingestion_destination(params = {}) ⇒ Types::CreateIngestionDestinationResponse
Creates an ingestion destination, which specifies how an application’s ingested data is processed by Amazon Web Services AppFabric and where it’s delivered.
983 984 985 986 |
# File 'lib/aws-sdk-appfabric/client.rb', line 983 def create_ingestion_destination(params = {}, = {}) req = build_request(:create_ingestion_destination, params) req.send_request() end |
#delete_app_authorization(params = {}) ⇒ Struct
Deletes an app authorization. You must delete the associated ingestion before you can delete an app authorization.
1012 1013 1014 1015 |
# File 'lib/aws-sdk-appfabric/client.rb', line 1012 def (params = {}, = {}) req = build_request(:delete_app_authorization, params) req.send_request() end |
#delete_app_bundle(params = {}) ⇒ Struct
Deletes an app bundle. You must delete all associated app authorizations before you can delete an app bundle.
1036 1037 1038 1039 |
# File 'lib/aws-sdk-appfabric/client.rb', line 1036 def delete_app_bundle(params = {}, = {}) req = build_request(:delete_app_bundle, params) req.send_request() end |
#delete_ingestion(params = {}) ⇒ Struct
Deletes an ingestion. You must stop (disable) the ingestion and you must delete all associated ingestion destinations before you can delete an app ingestion.
1066 1067 1068 1069 |
# File 'lib/aws-sdk-appfabric/client.rb', line 1066 def delete_ingestion(params = {}, = {}) req = build_request(:delete_ingestion, params) req.send_request() end |
#delete_ingestion_destination(params = {}) ⇒ Struct
Deletes an ingestion destination.
This deletes the association between an ingestion and it’s destination. It doesn’t delete previously ingested data or the storage destination, such as the Amazon S3 bucket where the data is delivered. If the ingestion destination is deleted while the associated ingestion is enabled, the ingestion will fail and is eventually disabled.
1106 1107 1108 1109 |
# File 'lib/aws-sdk-appfabric/client.rb', line 1106 def delete_ingestion_destination(params = {}, = {}) req = build_request(:delete_ingestion_destination, params) req.send_request() end |
#get_app_authorization(params = {}) ⇒ Types::GetAppAuthorizationResponse
Returns information about an app authorization.
1150 1151 1152 1153 |
# File 'lib/aws-sdk-appfabric/client.rb', line 1150 def (params = {}, = {}) req = build_request(:get_app_authorization, params) req.send_request() end |
#get_app_bundle(params = {}) ⇒ Types::GetAppBundleResponse
Returns information about an app bundle.
1180 1181 1182 1183 |
# File 'lib/aws-sdk-appfabric/client.rb', line 1180 def get_app_bundle(params = {}, = {}) req = build_request(:get_app_bundle, params) req.send_request() end |
#get_ingestion(params = {}) ⇒ Types::GetIngestionResponse
Returns information about an ingestion.
1221 1222 1223 1224 |
# File 'lib/aws-sdk-appfabric/client.rb', line 1221 def get_ingestion(params = {}, = {}) req = build_request(:get_ingestion, params) req.send_request() end |
#get_ingestion_destination(params = {}) ⇒ Types::GetIngestionDestinationResponse
Returns information about an ingestion destination.
1270 1271 1272 1273 |
# File 'lib/aws-sdk-appfabric/client.rb', line 1270 def get_ingestion_destination(params = {}, = {}) req = build_request(:get_ingestion_destination, params) req.send_request() end |
#list_app_authorizations(params = {}) ⇒ Types::ListAppAuthorizationsResponse
Returns a list of all app authorizations configured for an app bundle.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1327 1328 1329 1330 |
# File 'lib/aws-sdk-appfabric/client.rb', line 1327 def (params = {}, = {}) req = build_request(:list_app_authorizations, params) req.send_request() end |
#list_app_bundles(params = {}) ⇒ Types::ListAppBundlesResponse
Returns a list of app bundles.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1373 1374 1375 1376 |
# File 'lib/aws-sdk-appfabric/client.rb', line 1373 def list_app_bundles(params = {}, = {}) req = build_request(:list_app_bundles, params) req.send_request() end |
#list_ingestion_destinations(params = {}) ⇒ Types::ListIngestionDestinationsResponse
Returns a list of all ingestion destinations configured for an ingestion.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1430 1431 1432 1433 |
# File 'lib/aws-sdk-appfabric/client.rb', line 1430 def list_ingestion_destinations(params = {}, = {}) req = build_request(:list_ingestion_destinations, params) req.send_request() end |
#list_ingestions(params = {}) ⇒ Types::ListIngestionsResponse
Returns a list of all ingestions configured for an app bundle.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1484 1485 1486 1487 |
# File 'lib/aws-sdk-appfabric/client.rb', line 1484 def list_ingestions(params = {}, = {}) req = build_request(:list_ingestions, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of tags for a resource.
1515 1516 1517 1518 |
# File 'lib/aws-sdk-appfabric/client.rb', line 1515 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#start_ingestion(params = {}) ⇒ Struct
Starts (enables) an ingestion, which collects data from an application.
1544 1545 1546 1547 |
# File 'lib/aws-sdk-appfabric/client.rb', line 1544 def start_ingestion(params = {}, = {}) req = build_request(:start_ingestion, params) req.send_request() end |
#start_user_access_tasks(params = {}) ⇒ Types::StartUserAccessTasksResponse
Starts the tasks to search user access status for a specific email address.
The tasks are stopped when the user access status data is found. The tasks are terminated when the API calls to the application time out.
1586 1587 1588 1589 |
# File 'lib/aws-sdk-appfabric/client.rb', line 1586 def start_user_access_tasks(params = {}, = {}) req = build_request(:start_user_access_tasks, params) req.send_request() end |
#stop_ingestion(params = {}) ⇒ Struct
Stops (disables) an ingestion.
1614 1615 1616 1617 |
# File 'lib/aws-sdk-appfabric/client.rb', line 1614 def stop_ingestion(params = {}, = {}) req = build_request(:stop_ingestion, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified resource.
1646 1647 1648 1649 |
# File 'lib/aws-sdk-appfabric/client.rb', line 1646 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes a tag or tags from a resource.
1673 1674 1675 1676 |
# File 'lib/aws-sdk-appfabric/client.rb', line 1673 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_app_authorization(params = {}) ⇒ Types::UpdateAppAuthorizationResponse
Updates an app authorization within an app bundle, which allows AppFabric to connect to an application.
If the app authorization was in a ‘connected` state, updating the app authorization will set it back to a `PendingConnect` state.
1747 1748 1749 1750 |
# File 'lib/aws-sdk-appfabric/client.rb', line 1747 def (params = {}, = {}) req = build_request(:update_app_authorization, params) req.send_request() end |
#update_ingestion_destination(params = {}) ⇒ Types::UpdateIngestionDestinationResponse
Updates an ingestion destination, which specifies how an application’s ingested data is processed by Amazon Web Services AppFabric and where it’s delivered.
1814 1815 1816 1817 |
# File 'lib/aws-sdk-appfabric/client.rb', line 1814 def update_ingestion_destination(params = {}, = {}) req = build_request(:update_ingestion_destination, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1843 1844 1845 |
# File 'lib/aws-sdk-appfabric/client.rb', line 1843 def waiter_names [] end |